[mainnet]
explorer_uri = "https://eth.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0x5BA1e12693Dc8F9c48aAD8770482f4739bEeD696"
chain_id = 1

[sepolia]
explorer_uri = "https://eth-sepolia.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 11155111

[goerli]
explorer_uri = "https://eth-goerli.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0x5BA1e12693Dc8F9c48aAD8770482f4739bEeD696"
chain_id = 5

[arbitrum]
explorer_uri = "https://arbitrum.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0x5B5CFE992AdAC0C9D48E05854B2d91C73a003858"
chain_id = 42161

[optimism-main]
explorer_uri = "https://optimism.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0x2DC0E2aa608532Da689e89e237dF582B783E552C"
chain_id = 10

[optimism-test]
explorer_uri = "https://optimism-sepolia.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0x2DC0E2aa608532Da689e89e237dF582B783E552C"
chain_id = 420

[polygon-main]
explorer_uri = "https://polygon.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "0xc8E51042792d7405184DfCa245F2d27B94D013b6"
chain_id = 137

[gnosis-main]
explorer_uri = "https://gnosis.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 100

[gnosis-test]
explorer_uri = "https://gnosis-chiado.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 10200

[base-main]
explorer_uri = "https://base.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 8453

[syscoin]
explorer_uri = "https://explorer.syscoin.org/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 57

[ethereumclassic]
explorer_uri = "https://etc.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 61

[nova-network]
explorer_uri = "https://explorer.novanetwork.io/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 87

[velas]
explorer_uri = "https://evmexplorer.velas.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 106

[thundercore]
explorer_uri = "https://explorer-mainnet.thundercore.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 108

[fuse]
explorer_uri = "https://explorer.fuse.io/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 122

[shimmer_evm]
explorer_uri = "https://explorer.evm.shimmer.network/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 148

[manta]
explorer_uri = "https://pacific-explorer.manta.network/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 169

[energyweb]
explorer_uri = "https://explorer.energyweb.org/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 246

[oasys]
explorer_uri = "https://explorer.oasys.games/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 248

[filecoin]
explorer_uri = "https://filecoin.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 314

[zksync-era]
explorer_uri = "https://zksync2-mainnet-explorer.zksync.io"
explorer_type = "zksyncexplorer"
multicall2 = "None"
chain_id = 324

[sepolia-zksync-era]
explorer_uri = "https://explorer.sepolia.era.zksync.dev"
explorer_type = "zksyncexplorer"
multicall2 = "None"
chain_id = 300

[shiden]
explorer_uri = "https://shiden.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 336

[rollux]
explorer_uri = "https://explorer.rollux.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 570

[astar]
explorer_uri = "https://astar.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 592

[callisto]
explorer_uri = "https://explorer.callisto.network/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 820

[lyra-chain]
explorer_uri = "https://explorer.lyra.finance/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 957

[bifrost]
explorer_uri = "https://explorer.mainnet.bifrostnetwork.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 996

[metis]
explorer_uri = "https://andromeda-explorer.metis.io/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1088

[polygon-zkevm]
explorer_uri = "https://zkevm.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1101

[lisk]
explorer_uri = "https://blockscout.lisk.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1135

[reya-network]
explorer_uri = "https://explorer.reya.network/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1729

[onus]
explorer_uri = "https://explorer.onuschain.io/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1975

[sanko]
explorer_uri = "https://explorer.sanko.xyz/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1996

[dogechain]
explorer_uri = "https://explorer.dogechain.dog/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 2000

[milkomeda]
explorer_uri = "https://explorer-mainnet-cardano-evm.c1.milkomeda.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 2001

[kava]
explorer_uri = "https://testnet.kavascan.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 2222

[mantle]
explorer_uri = "https://explorer.mantle.xyz/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 5000

[zetachain]
explorer_uri = "https://zetachain.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 7000

[celo]
explorer_uri = "https://explorer.celo.org/mainnet/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 42220

[oasis]
explorer_uri = "https://explorer.emerald.oasis.dev/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 42262

[linea]
explorer_uri = "https://explorer.linea.build/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 59144

[blast]
explorer_uri = "https://blast.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 81457

[taiko]
explorer_uri = "https://blockscoutapi.mainnet.taiko.xyz/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 167000

[scroll]
explorer_uri = "https://blockscout.scroll.io/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 534352

[zora]
explorer_uri = "https://explorer.zora.energy/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 7777777

[neon]
explorer_uri = "https://neon.blockscout.com/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 245022934

[aurora]
explorer_uri = "https://explorer.mainnet.aurora.dev/"
explorer_type = "blockscout"
multicall2 = "None"
chain_id = 1313161554
